@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright 2014-2015 Sebastian Kügler <sebas@kde.org>                             *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2014-2015 Sebastian Kügler <sebas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 #include "waylandoutput.h"
 #include "../utils.h"
 #include "waylandbackend.h"
@@ -181,6 +169,9 @@ void WaylandOutput::updateKScreenOutput(OutputPtr &output)
     output->setModes(modeList);
     output->setScale(m_device->scaleF());
     output->setType(Utils::guessOutputType(m_device->model(), m_device->model()));
+    output->setCapabilities(static_cast<Output::Capabilities>(static_cast<uint32_t>(m_device->capabilities())));
+    output->setOverscan(m_device->overscan());
+    output->setVrrPolicy(static_cast<Output::VrrPolicy>(m_device->vrrPolicy()));
 }
 
 bool WaylandOutput::setWlConfig(Wl::OutputConfiguration *wlConfig, const KScreen::OutputPtr &output)
@@ -222,6 +213,19 @@ bool WaylandOutput::setWlConfig(Wl::OutputConfiguration *wlConfig, const KScreen
     } else {
         qCWarning(KSCREEN_WAYLAND) << "Invalid kscreen mode id:" << output->currentModeId() << "\n\n" << m_modeIdMap;
     }
+
+    // overscan
+    if ((output->capabilities() & Output::Capability::Overscan) && m_device->overscan() != output->overscan()) {
+        wlConfig->setOverscan(m_device, output->overscan());
+        changed = true;
+    }
+
+    // vrr
+    if ((output->capabilities() & Output::Capability::Vrr) && m_device->vrrPolicy() != static_cast<Wl::OutputDevice::VrrPolicy>(output->vrrPolicy())) {
+        wlConfig->setVrrPolicy(m_device, static_cast<Wl::OutputDevice::VrrPolicy>(output->vrrPolicy()));
+        changed = true;
+    }
+
     return changed;
 }
 
