@@ -1,36 +1,23 @@
-/*************************************************************************************
- *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *  Copyright (C) 2014 by Daniel Vrátil <dvratil@redhat.com>                         *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #ifndef KSCREEN_CONFIG_H
 #define KSCREEN_CONFIG_H
 
+#include "kscreen_export.h"
 #include "screen.h"
 #include "types.h"
-#include "kscreen_export.h"
 
 #include <QHash>
-#include <QObject>
 #include <QMetaType>
+#include <QObject>
 
-
-namespace KScreen {
-
+namespace KScreen
+{
 /**
  * Represents a (or the) screen configuration.
  *
@@ -49,10 +36,10 @@ class KSCREEN_EXPORT Config : public QObject
     Q_PROPERTY(ScreenPtr screen READ screen)
     Q_PROPERTY(OutputList outputs READ outputs)
 
-  public:
+public:
     enum class ValidityFlag {
         None = 0x0,
-        RequireAtLeastOneEnabledScreen = 0x1
+        RequireAtLeastOneEnabledScreen = 0x1,
     };
     Q_DECLARE_FLAGS(ValidityFlags, ValidityFlag)
 
@@ -203,24 +190,22 @@ class KSCREEN_EXPORT Config : public QObject
      */
     void setTabletModeEngaged(bool engaged);
 
-  Q_SIGNALS:
-      void outputAdded(const KScreen::OutputPtr &output);
-      void outputRemoved(int outputId);
-      void primaryOutputChanged(const KScreen::OutputPtr &output);
+Q_SIGNALS:
+    void outputAdded(const KScreen::OutputPtr &output);
+    void outputRemoved(int outputId);
+    void primaryOutputChanged(const KScreen::OutputPtr &output);
 
-  private:
+private:
     Q_DISABLE_COPY(Config)
 
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
-} //KScreen namespace
+} // KScreen namespace
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KScreen::Config::Features)
 
 KSCREEN_EXPORT QDebug operator<<(QDebug dbg, const KScreen::ConfigPtr &config);
 
-
-
-#endif //KSCREEN_CONFIG_H
+#endif // KSCREEN_CONFIG_H
