@@ -1,21 +1,9 @@
-/*************************************************************************************
- *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *  Copyright (C) 2014 by Daniel Vrátil <dvratil@redhat.com>                         *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "output.h"
 #include "abstractbackend.h"
@@ -67,8 +55,12 @@ public:
         , enabled(other.enabled)
         , primary(other.primary)
         , followPreferredMode(other.followPreferredMode)
+        , capabilities(other.capabilities)
+        , overscan(other.overscan)
+        , vrrPolicy(other.vrrPolicy)
     {
-        Q_FOREACH (const ModePtr &otherMode, other.modeList) {
+        const auto otherModeList = other.modeList;
+        for (const ModePtr &otherMode : otherModeList) {
             modeList.insert(otherMode->id(), otherMode->clone());
         }
         if (other.edid) {
@@ -99,6 +91,9 @@ public:
     bool enabled;
     bool primary;
     bool followPreferredMode = false;
+    Capabilities capabilities;
+    uint32_t overscan = 0;
+    VrrPolicy vrrPolicy = VrrPolicy::Automatic;
 
     QScopedPointer<Edid> edid;
 };
@@ -137,7 +132,7 @@ QString Output::Private::biggestMode(const ModeList &modes) const
 {
     int area, total = 0;
     KScreen::ModePtr biggest;
-    Q_FOREACH (const KScreen::ModePtr &mode, modes) {
+    for (const KScreen::ModePtr &mode : modes) {
         area = mode->size().width() * mode->size().height();
         if (area < total) {
             continue;
@@ -284,8 +279,8 @@ void Output::setModes(const ModeList &modes)
     bool changed = !d->compareModeList(d->modeList, modes);
     d->modeList = modes;
     if (changed) {
-        emit modesChanged();
-        emit outputChanged();
+        Q_EMIT modesChanged();
+        Q_EMIT outputChanged();
     }
 }
 
@@ -333,7 +328,7 @@ QString Output::preferredModeId() const
     int total = 0;
     KScreen::ModePtr biggest;
     KScreen::ModePtr candidateMode;
-    Q_FOREACH (const QString &modeId, d->preferredModes) {
+    for (const QString &modeId : qAsConst(d->preferredModes)) {
         candidateMode = mode(modeId);
         const int area = candidateMode->size().width() * candidateMode->size().height();
         if (area < total) {
@@ -422,7 +417,7 @@ void Output::setScale(qreal factor)
         return;
     }
     d->scale = factor;
-    emit scaleChanged();
+    Q_EMIT scaleChanged();
 }
 
 QSizeF Output::logicalSize() const
@@ -602,6 +597,45 @@ QRect Output::geometry() const
     return QRect(d->pos, size);
 }
 
+Output::Capabilities Output::capabilities() const
+{
+    return d->capabilities;
+}
+
+void Output::setCapabilities(Capabilities capabilities)
+{
+    if (d->capabilities != capabilities) {
+        d->capabilities = capabilities;
+        Q_EMIT capabilitiesChanged(capabilities);
+    }
+}
+
+uint32_t Output::overscan() const
+{
+    return d->overscan;
+}
+
+void Output::setOverscan(uint32_t overscan)
+{
+    if (d->overscan != overscan) {
+        d->overscan = overscan;
+        Q_EMIT overscanChanged(overscan);
+    }
+}
+
+Output::VrrPolicy Output::vrrPolicy() const
+{
+    return d->vrrPolicy;
+}
+
+void Output::setVrrPolicy(VrrPolicy policy)
+{
+    if (d->vrrPolicy != policy) {
+        d->vrrPolicy = policy;
+        Q_EMIT vrrPolicyChanged();
+    }
+}
+
 void Output::apply(const OutputPtr &other)
 {
     typedef void (KScreen::Output::*ChangeSignal)();
@@ -669,7 +703,7 @@ void Output::apply(const OutputPtr &other)
 
     setPreferredModes(other->d->preferredModes);
     ModeList modes;
-    Q_FOREACH (const ModePtr &otherMode, other->modes()) {
+    for (const ModePtr &otherMode : other->modes()) {
         modes.insert(otherMode->id(), otherMode->clone());
     }
     setModes(modes);
